==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/Xml2MetalinkProcessor.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_XML2_METALINK_PROCESSOR_H_
#define _D_XML2_METALINK_PROCESSOR_H_

#include "MetalinkProcessor.h"
#include <libxml/parser.h>
#include <libxml/xpath.h>

class Xml2MetalinkProcessor : public MetalinkProcessor {
private:
  xmlDocPtr doc;
  xmlXPathContextPtr context;

  MetalinkEntryHandle getEntry(const string& xpath);
  MetalinkResourceHandle getResource(const string& xpath);

  xmlXPathObjectPtr xpathEvaluation(const string& xpath);
  string xpathContent(const string& xpath);
  string xmlAttribute(xmlNodePtr node, const string& attrName);
  string xmlContent(xmlNodePtr node);

  void release();
public:
  Xml2MetalinkProcessor();
  virtual ~Xml2MetalinkProcessor();

  virtual MetalinkerHandle parseFile(const string& filename);
  
};

#endif // _D_XML2_METALINK_PROCESSOR_H_

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/Xml2MetalinkProcessor.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_XML2_METALINK_PROCESSOR_H_
#define _D_XML2_METALINK_PROCESSOR_H_

#include "MetalinkProcessor.h"
#include <libxml/parser.h>
#include <libxml/xpath.h>

class Xml2MetalinkProcessor : public MetalinkProcessor {
private:
  xmlDocPtr doc;
  xmlXPathContextPtr context;

  MetalinkEntryHandle getEntry(const string& xpath);
  MetalinkResourceHandle getResource(const string& xpath);

#ifdef ENABLE_MESSAGE_DIGEST
  MetalinkChunkChecksumHandle getPieceHash(const string& xpath,
					   int64_t totalSize);
#endif // ENABLE_MESSAGE_DIGEST

  xmlXPathObjectPtr xpathEvaluation(const string& xpath);
  string xpathContent(const string& xpath);
  string xmlAttribute(xmlNodePtr node, const string& attrName);
  string xmlContent(xmlNodePtr node);
  bool xpathExists(const string& xpath);

  void release();
public:
  Xml2MetalinkProcessor();
  virtual ~Xml2MetalinkProcessor();

  virtual MetalinkerHandle parseFile(const string& filename);
  
};

#endif // _D_XML2_METALINK_PROCESSOR_H_
